import { createContext, useContext, useMemo } from "react";

export type AuthorData = {
    // 운영자
    type: "operator";
} | {
    // 고닉
    // 중복 불가능 닉네임
    type: "nickname";
    nickname: string;
    // 파딱, 주딱 구분을 위한 userType
    userType?: "manager" | "submanager"; // Optional, if applicable
} | {
    // 유동닉
    type: "IP";
    // IP 주소
    ip: string;

    tempNickname?: string; // Optional, if applicable
} | {
    // 반유동닉
    // 중복 가능 닉네임
    type: "semi-nickname";
    nickname: string;
};

const NicknameImagePath = {
    "주딱": "/fix_managernik.gif",
    "파딱": "/fix_sub_managernik.gif",
    "반유동": "/nik.gif",
    "default": "/fix_nik.gif"
}

const AnnoymousNickName = createContext("ㅇㅇ");
export const AnnoymousNickNameProvider = AnnoymousNickName.Provider;

export function NickName({ author } : {
    author: AuthorData,
}) {
    const defaultNickname = useContext(AnnoymousNickName);

    const nickname = useMemo(() => {
        switch (author.type) {
            case "nickname":
                return author.nickname;
            case "semi-nickname":
                return author.nickname;
            case "IP":
                return author.tempNickname ?? defaultNickname;
            case "operator":
                return "운영자";
            default:
                return defaultNickname;
        }
    }, [author, defaultNickname])
    
    return <>
        {/* Author Name Span */}
        <span className="inline-block max-w-[81%] align-top text-ellipsis overflow-hidden whitespace-nowrap">
            {/* Inner em/span for potential finer control if needed */}
            <em className="not-italic leading-[13px]">
                {nickname}
            </em>
        </span>
        {/* Author IP */}
        {author?.type === "IP" && (
            <span className="font-tahoma text-[11px] text-custom-gray-medium tracking-[-0.05em] ml-[3px]">
                ({author.ip})
            </span>
        )}
        {/* Author Icon Placeholder */}
        {author?.type !== "IP" && (
            <a className="text-custom-gray-dark ml-0.5 inline-block">
                {/* Replace with actual icon component or img tag */}
                <img
                    alt="icon"
                    src={
                        author?.type === "nickname" ? (
                            author?.userType === "manager" ? NicknameImagePath["주딱"] :
                                author?.userType === "submanager" ? NicknameImagePath["파딱"] :
                                    NicknameImagePath["default"]
                        ) : NicknameImagePath["반유동"]
                    }
                    className="align-middle cursor-pointer w-3 h-3" // Example size
                />
            </a>
        )}
    </>
}